pub struct PrefixCache { /* private fields */ }Expand description
Main prefix cache manager
Implementations
Sourceimpl PrefixCache
impl PrefixCache
Sourcepub fn new(
max_sessions: usize,
ttl_seconds: u64,
frequency_threshold: usize,
session_dir: Option<PathBuf>,
) -> Result<Self>
pub fn new( max_sessions: usize, ttl_seconds: u64, frequency_threshold: usize, session_dir: Option<PathBuf>, ) -> Result<Self>
Sourcepub fn find_prefix_session(
&self,
text: &str,
tokens: &[i32],
) -> Option<(usize, Arc<SessionData>)>
pub fn find_prefix_session( &self, text: &str, tokens: &[i32], ) -> Option<(usize, Arc<SessionData>)>
Check if a text has a cached prefix and return the session
Sourcepub fn register_prefix(
&self,
text: &str,
tokens: &[i32],
session_data: Vec<u8>,
) -> Result<()>
pub fn register_prefix( &self, text: &str, tokens: &[i32], session_data: Vec<u8>, ) -> Result<()>
Register a new prefix for caching
Errors
Returns an error if the cache is full and cannot evict enough entries
Sourcepub fn stats(&self) -> PrefixCacheStats
pub fn stats(&self) -> PrefixCacheStats
Get cache statistics